@@ -1,12 +1,12 @@
 // cellStyle
 use super::StringValue;
 use super::UInt32Value;
-use reader::driver::*;
-use writer::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct CellStyle {
@@ -15,55 +15,55 @@ pub struct CellStyle {
     format_id: UInt32Value,
 }
 impl CellStyle {
-    pub fn get_name(&self)-> &str {
+    pub fn get_name(&self) -> &str {
         &self.name.get_value()
     }
 
-    pub fn set_name<S: Into<String>>(&mut self, value:S)-> &mut Self {
+    pub fn set_name<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.name.set_value(value);
         self
     }
 
-    pub fn get_builtin_id(&self)-> &u32 {
+    pub fn get_builtin_id(&self) -> &u32 {
         &self.builtin_id.get_value()
     }
 
-    pub fn set_builtin_id(&mut self, value:u32)-> &mut Self {
+    pub fn set_builtin_id(&mut self, value: u32) -> &mut Self {
         self.builtin_id.set_value(value);
         self
     }
 
-    pub fn get_format_id(&self)-> &u32 {
+    pub fn get_format_id(&self) -> &u32 {
         &self.format_id.get_value()
     }
 
-    pub fn set_format_id(&mut self, value:u32)-> &mut Self {
+    pub fn set_format_id(&mut self, value: u32) -> &mut Self {
         self.format_id.set_value(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         match get_attribute(e, b"name") {
             Some(v) => {
                 self.name.set_value_string(v);
-            },
-            None => {},
+            }
+            None => {}
         }
         match get_attribute(e, b"xfId") {
             Some(v) => {
                 self.builtin_id.set_value_string(v);
-            },
-            None => {},
+            }
+            None => {}
         }
         match get_attribute(e, b"builtinId") {
             Some(v) => {
                 self.format_id.set_value_string(v);
-            },
-            None => {},
+            }
+            None => {}
         }
     }
 
@@ -75,4 +75,4 @@ impl CellStyle {
         attributes.push(("builtinId", &self.format_id.get_value_string()));
         write_start_tag(writer, "cellStyle", attributes, true);
     }
-}
\ No newline at end of file
+}
