@@ -15,7 +15,7 @@ impl CellStyleFormats {
         &self.cell_format
     }
 
-    pub(crate) fn get_cell_format_mut(&mut self) -> &mut Vec<CellFormat> {
+    pub(crate) fn _get_cell_format_mut(&mut self) -> &mut Vec<CellFormat> {
         &mut self.cell_format
     }
 
