@@ -1,9 +1,9 @@
 use super::Cell;
 use super::CellValue;
 use super::Style;
-use std::collections::HashMap;
-use std::collections::BTreeMap;
 use helper::range::*;
+use std::collections::BTreeMap;
+use std::collections::HashMap;
 
 #[derive(Clone, Default, Debug)]
 pub struct Cells {
@@ -12,15 +12,15 @@ pub struct Cells {
     default_style: Style,
 }
 impl Cells {
-    pub(crate) fn get_collection(&self)-> &Vec<Cell> {
+    pub(crate) fn get_collection(&self) -> &Vec<Cell> {
         &self.index
     }
 
-    pub(crate) fn get_collection_mut(&mut self)-> &mut Vec<Cell> {
+    pub(crate) fn get_collection_mut(&mut self) -> &mut Vec<Cell> {
         &mut self.index
     }
 
-    pub(crate) fn get_collection_to_hashmap(&self)-> HashMap<String, &Cell> {
+    pub(crate) fn get_collection_to_hashmap(&self) -> HashMap<String, &Cell> {
         let mut result = HashMap::default();
         for cell in &self.index {
             let coordinate = cell.get_coordinate().get_coordinate();
@@ -29,7 +29,7 @@ impl Cells {
         result
     }
 
-    pub(crate) fn get_collection_by_row(&self, row_num:&u32)-> BTreeMap<u32, &Cell> {
+    pub(crate) fn get_collection_by_row(&self, row_num: &u32) -> BTreeMap<u32, &Cell> {
         let mut result = BTreeMap::default();
         for cell in &self.index {
             if row_num == cell.get_coordinate().get_row_num() {
@@ -39,9 +39,19 @@ impl Cells {
         result
     }
 
-    pub(crate) fn get_highest_row_and_column(&self)-> HashMap<&str, &u32> {
-        let mut col_max:&u32 = &0;
-        let mut row_max:&u32 = &0;
+    pub(crate) fn get_collection_by_column(&self, column_num: &u32) -> BTreeMap<u32, &Cell> {
+        let mut result = BTreeMap::default();
+        for cell in &self.index {
+            if column_num == cell.get_coordinate().get_col_num() {
+                result.insert(cell.get_coordinate().get_row_num().clone(), cell);
+            }
+        }
+        result
+    }
+
+    pub(crate) fn get_highest_row_and_column(&self) -> HashMap<&str, &u32> {
+        let mut col_max: &u32 = &0;
+        let mut row_max: &u32 = &0;
         for cell in &self.index {
             if cell.get_coordinate().get_col_num() > &col_max {
                 col_max = cell.get_coordinate().get_col_num();
@@ -56,7 +66,7 @@ impl Cells {
         result
     }
 
-    pub(crate) fn has(&self, col_num:&u32, row_num:&u32) -> bool {
+    pub(crate) fn has(&self, col_num: &u32, row_num: &u32) -> bool {
         for cell in &self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
                 return true;
@@ -65,7 +75,7 @@ impl Cells {
         false
     }
 
-    pub(crate) fn get(&self, col_num:&u32, row_num:&u32) -> Option<&Cell> {
+    pub(crate) fn get(&self, col_num: &u32, row_num: &u32) -> Option<&Cell> {
         for cell in &self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
                 return Some(cell);
@@ -74,7 +84,7 @@ impl Cells {
         None
     }
 
-    pub(crate) fn get_crate(&mut self, col_num:&u32, row_num:&u32) -> Option<&mut Cell> {
+    pub(crate) fn get_crate(&mut self, col_num: &u32, row_num: &u32) -> Option<&mut Cell> {
         for cell in &mut self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
                 return Some(cell);
@@ -83,7 +93,7 @@ impl Cells {
         None
     }
 
-    pub(crate) fn get_mut(&mut self, col_num:&u32, row_num:&u32) -> &mut Cell {
+    pub(crate) fn get_mut(&mut self, col_num: &u32, row_num: &u32) -> &mut Cell {
         if self.has(col_num, row_num) == false {
             let mut cell = Cell::default();
             cell.get_coordinate_mut().set_col_num(col_num.clone());
@@ -93,7 +103,7 @@ impl Cells {
         self.get_crate(col_num, row_num).unwrap()
     }
 
-    pub(crate) fn get_cell_value(&self, col_num:&u32, row_num:&u32) -> &CellValue {
+    pub(crate) fn get_cell_value(&self, col_num: &u32, row_num: &u32) -> &CellValue {
         for cell in &self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
                 return cell.get_cell_value();
@@ -102,7 +112,7 @@ impl Cells {
         &self.default_cell_value
     }
 
-    pub(crate) fn get_style(&self, col_num:&u32, row_num:&u32) -> &Style {
+    pub(crate) fn get_style(&self, col_num: &u32, row_num: &u32) -> &Style {
         for cell in &self.index {
             if cell.get_coordinate().is_mine(col_num, row_num) {
                 return cell.get_style();
@@ -111,22 +121,21 @@ impl Cells {
         &self.default_style
     }
 
-    pub(crate) fn set(&mut self, cell:Cell) -> &mut Self {
+    pub(crate) fn set(&mut self, cell: Cell) -> &mut Self {
         let col_num = cell.get_coordinate().get_col_num();
         let row_num = cell.get_coordinate().get_row_num();
-        self.index.retain(|x| {
-            !x.get_coordinate().is_mine(col_num, row_num)
-        });
+        self.index
+            .retain(|x| !x.get_coordinate().is_mine(col_num, row_num));
         self.add(cell);
         self
     }
 
-    pub(crate) fn add(&mut self, cell:Cell) {
+    pub(crate) fn add(&mut self, cell: Cell) {
         self.index.push(cell);
     }
 
-    pub(crate) fn get_cell_value_by_range<S: Into<String>>(&self, range:S) -> Vec<&CellValue> {
-        let mut result:Vec<&CellValue> = Vec::new();
+    pub(crate) fn get_cell_value_by_range<S: Into<String>>(&self, range: S) -> Vec<&CellValue> {
+        let mut result: Vec<&CellValue> = Vec::new();
         let range_upper = range.into().to_uppercase();
         let coordinate_list = get_coordinate_list(&range_upper);
         for (col_num, row_num) in coordinate_list {
@@ -134,4 +143,4 @@ impl Cells {
         }
         result
     }
-}
\ No newline at end of file
+}
