@@ -1,16 +1,16 @@
 // c:area3DChart
-use super::Grouping;
-use super::VaryColors;
 use super::AreaChartSeries;
 use super::AreaChartSeriesList;
-use super::DataLabels;
 use super::AxisId;
-use structs::Spreadsheet;
-use writer::driver::*;
+use super::DataLabels;
+use super::Grouping;
+use super::VaryColors;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use structs::Spreadsheet;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Area3DChart {
@@ -21,118 +21,113 @@ pub struct Area3DChart {
     axis_id: Vec<AxisId>,
 }
 impl Area3DChart {
-    pub fn get_grouping(&self)-> &Grouping {
+    pub fn get_grouping(&self) -> &Grouping {
         &self.grouping
     }
 
-    pub fn get_grouping_mut(&mut self)-> &mut Grouping {
+    pub fn get_grouping_mut(&mut self) -> &mut Grouping {
         &mut self.grouping
     }
 
-    pub fn set_grouping(&mut self, value:Grouping)-> &mut Area3DChart {
+    pub fn set_grouping(&mut self, value: Grouping) -> &mut Area3DChart {
         self.grouping = value;
         self
     }
 
-    pub fn get_vary_colors(&self)-> &VaryColors {
+    pub fn get_vary_colors(&self) -> &VaryColors {
         &self.vary_colors
     }
 
-    pub fn get_vary_colors_mut(&mut self)-> &mut VaryColors {
+    pub fn get_vary_colors_mut(&mut self) -> &mut VaryColors {
         &mut self.vary_colors
     }
 
-    pub fn set_vary_colors(&mut self, value:VaryColors)-> &mut Area3DChart {
+    pub fn set_vary_colors(&mut self, value: VaryColors) -> &mut Area3DChart {
         self.vary_colors = value;
         self
     }
 
-    pub fn get_area_chart_series_list(&self)-> &AreaChartSeriesList {
+    pub fn get_area_chart_series_list(&self) -> &AreaChartSeriesList {
         &self.area_chart_series_list
     }
 
-    pub fn get_area_chart_series_list_mut(&mut self)-> &mut AreaChartSeriesList {
+    pub fn get_area_chart_series_list_mut(&mut self) -> &mut AreaChartSeriesList {
         &mut self.area_chart_series_list
     }
 
-    pub fn set_area_chart_series_list(&mut self, value:AreaChartSeriesList)-> &mut Self {
+    pub fn set_area_chart_series_list(&mut self, value: AreaChartSeriesList) -> &mut Self {
         self.area_chart_series_list = value;
         self
     }
 
-    pub fn get_data_labels(&self)-> &DataLabels {
+    pub fn get_data_labels(&self) -> &DataLabels {
         &self.data_labels
     }
 
-    pub fn get_data_labels_mut(&mut self)-> &mut DataLabels {
+    pub fn get_data_labels_mut(&mut self) -> &mut DataLabels {
         &mut self.data_labels
     }
 
-    pub fn set_data_labels(&mut self, value:DataLabels)-> &mut Area3DChart {
+    pub fn set_data_labels(&mut self, value: DataLabels) -> &mut Area3DChart {
         self.data_labels = value;
         self
     }
 
-    pub fn get_axis_id(&self)-> &Vec<AxisId> {
+    pub fn get_axis_id(&self) -> &Vec<AxisId> {
         &self.axis_id
     }
 
-    pub fn get_axis_id_mut(&mut self)-> &mut Vec<AxisId> {
+    pub fn get_axis_id_mut(&mut self) -> &mut Vec<AxisId> {
         &mut self.axis_id
     }
 
-    pub fn set_axis_id(&mut self, value:Vec<AxisId>)-> &mut Area3DChart {
+    pub fn set_axis_id(&mut self, value: Vec<AxisId>) -> &mut Area3DChart {
         self.axis_id = value;
         self
     }
 
-    pub fn add_axis_id(&mut self, value:AxisId)-> &mut Area3DChart {
+    pub fn add_axis_id(&mut self, value: AxisId) -> &mut Area3DChart {
         self.axis_id.push(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        _e:&BytesStart
+        reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
         let mut buf = Vec::new();
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"c:ser" => {
-                            let mut obj = AreaChartSeries::default();
-                            obj.set_attributes(reader, e);
-                            self.get_area_chart_series_list_mut().add_area_chart_series(obj);
-                        },
-                        b"c:dLbls" => {
-                            self.data_labels.set_attributes(reader, e);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"c:ser" => {
+                        let mut obj = AreaChartSeries::default();
+                        obj.set_attributes(reader, e);
+                        self.get_area_chart_series_list_mut()
+                            .add_area_chart_series(obj);
                     }
+                    b"c:dLbls" => {
+                        self.data_labels.set_attributes(reader, e);
+                    }
+                    _ => (),
                 },
-                Ok(Event::Empty(ref e)) => {
-                    match e.name() {
-                        b"c:grouping" => {
-                            self.grouping.set_attributes(reader, e);
-                        },
-                        b"c:varyColors" => {
-                            self.vary_colors.set_attributes(reader, e);
-                        },
-                        b"c:axId" => {
-                            let mut obj = AxisId::default();
-                            obj.set_attributes(reader, e);
-                            self.add_axis_id(obj);
-                        },
-                        _ => (),
+                Ok(Event::Empty(ref e)) => match e.name() {
+                    b"c:grouping" => {
+                        self.grouping.set_attributes(reader, e);
                     }
+                    b"c:varyColors" => {
+                        self.vary_colors.set_attributes(reader, e);
+                    }
+                    b"c:axId" => {
+                        let mut obj = AxisId::default();
+                        obj.set_attributes(reader, e);
+                        self.add_axis_id(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"c:area3DChart" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"c:area3DChart" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "c:area3DChart"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
