@@ -1,11 +1,11 @@
 // a:stCxn
 use super::super::super::UInt32Value;
-use writer::driver::*;
-use reader::driver::*;
-use quick_xml::events::{BytesStart};
-use quick_xml::Writer;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
+use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct StartConnection {
@@ -17,7 +17,7 @@ impl StartConnection {
         &self.id.get_value()
     }
 
-    pub fn set_id(&mut self, value:u32) {
+    pub fn set_id(&mut self, value: u32) {
         self.id.set_value(value);
     }
 
@@ -25,23 +25,30 @@ impl StartConnection {
         &self.index.get_value()
     }
 
-    pub fn set_index(&mut self, value:u32) {
+    pub fn set_index(&mut self, value: u32) {
         self.index.set_value(value);
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         &mut self.id.set_value_string(get_attribute(e, b"id").unwrap());
-        &mut self.index.set_value_string(get_attribute(e, b"idx").unwrap());
+        &mut self
+            .index
+            .set_value_string(get_attribute(e, b"idx").unwrap());
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
-        write_start_tag(writer, "a:stCxn", vec![
-            ("id", &self.id.get_value_string()),
-            ("idx", &self.index.get_value_string()),
-        ], true);
+        write_start_tag(
+            writer,
+            "a:stCxn",
+            vec![
+                ("id", &self.id.get_value_string()),
+                ("idx", &self.index.get_value_string()),
+            ],
+            true,
+        );
     }
 }
