@@ -1,43 +1,48 @@
 // family
 use super::Int32Value;
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct FontFamilyNumbering {
     pub(crate) val: Int32Value,
 }
 impl FontFamilyNumbering {
-    pub fn get_val(&self)-> &i32 {
+    pub fn get_val(&self) -> &i32 {
         &self.val.get_value()
     }
-    
-    pub fn set_val(&mut self, value:i32)-> &mut Self {
+
+    pub fn set_val(&mut self, value: i32) -> &mut Self {
         self.val.set_value(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         match get_attribute(e, b"val") {
-            Some(v) => {self.val.set_value_string(v);},
-            None => {},
+            Some(v) => {
+                self.val.set_value_string(v);
+            }
+            None => {}
         }
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // family
         if &self.val.has_value() == &true {
-            write_start_tag(writer, "family", vec![
-                ("val", &self.val.get_value_string()),
-            ], true);
+            write_start_tag(
+                writer,
+                "family",
+                vec![("val", &self.val.get_value_string())],
+                true,
+            );
         }
     }
 }
