@@ -1,4 +1,2 @@
 #[derive(Clone, Default, Debug)]
-pub struct HeaderFooterDrawing {
-
-}
+pub struct HeaderFooterDrawing {}
