@@ -15,7 +15,7 @@ impl MruColors {
         &self.color
     }
 
-    pub(crate) fn get_color_mut(&mut self) -> &mut Vec<Color> {
+    pub(crate) fn _get_color_mut(&mut self) -> &mut Vec<Color> {
         &mut self.color
     }
 
