@@ -1,17 +1,17 @@
-use super::Worksheet;
+use super::Calculation;
+use super::Image;
 use super::Properties;
 use super::Security;
-use super::Calculation;
-use super::Style;
-use super::Image;
-use super::Theme;
-use super::Stylesheet;
 use super::SharedStringTable;
+use super::Style;
+use super::Stylesheet;
+use super::Theme;
 use super::WorkbookView;
-use structs::CellValue;
-use structs::Address;
-use helper::coordinate::*;
+use super::Worksheet;
 use helper::address::*;
+use helper::coordinate::*;
+use structs::Address;
+use structs::CellValue;
 
 #[derive(Clone, Default, Debug)]
 pub struct Spreadsheet {
@@ -54,7 +54,12 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_row("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_row<S: Into<String>>(&mut self, sheet_name:S, row_index:u32, num_rows:u32) {
+    pub fn insert_new_row<S: Into<String>>(
+        &mut self,
+        sheet_name: S,
+        row_index: u32,
+        num_rows: u32,
+    ) {
         self.adjustment_insert_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
     }
 
@@ -68,7 +73,12 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_colmun("Sheet1", "B", 3);
     /// ```
-    pub fn insert_new_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:u32) {
+    pub fn insert_new_colmun<S: Into<String>>(
+        &mut self,
+        sheet_name: S,
+        column: S,
+        num_columns: u32,
+    ) {
         let column_upper = column.into().to_uppercase();
         let column_index = column_index_from_string(column_upper);
         self.insert_new_colmun_by_index(&sheet_name.into(), column_index, num_columns);
@@ -84,7 +94,12 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.insert_new_colmun_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn insert_new_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:u32, num_columns:u32) {
+    pub fn insert_new_colmun_by_index<S: Into<String>>(
+        &mut self,
+        sheet_name: S,
+        column_index: u32,
+        num_columns: u32,
+    ) {
         self.adjustment_insert_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
     }
 
@@ -98,7 +113,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_row("Sheet1", 2, 3);
     /// ```
-    pub fn remove_row<S: Into<String>>(&mut self, sheet_name:S, row_index:u32, num_rows:u32) {
+    pub fn remove_row<S: Into<String>>(&mut self, sheet_name: S, row_index: u32, num_rows: u32) {
         self.adjustment_remove_coordinate(&sheet_name.into(), &0, &0, &row_index, &num_rows);
     }
 
@@ -112,7 +127,7 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_colmun("Sheet1", "B", 3);
     /// ```
-    pub fn remove_colmun<S: Into<String>>(&mut self, sheet_name:S, column:S, num_columns:u32) {
+    pub fn remove_colmun<S: Into<String>>(&mut self, sheet_name: S, column: S, num_columns: u32) {
         let column_upper = column.into().to_uppercase();
         let column_index = column_index_from_string(column_upper);
         self.remove_colmun_by_index(&sheet_name.into(), column_index, num_columns);
@@ -128,25 +143,55 @@ impl Spreadsheet {
     /// let mut book = umya_spreadsheet::new_file();
     /// book.remove_colmun_by_index("Sheet1", 2, 3);
     /// ```
-    pub fn remove_colmun_by_index<S: Into<String>>(&mut self, sheet_name:S, column_index:u32, num_columns:u32) {
+    pub fn remove_colmun_by_index<S: Into<String>>(
+        &mut self,
+        sheet_name: S,
+        column_index: u32,
+        num_columns: u32,
+    ) {
         self.adjustment_remove_coordinate(&sheet_name.into(), &column_index, &num_columns, &0, &0);
     }
 
-    pub(crate) fn adjustment_insert_coordinate(&mut self, sheet_name:&str, column_index:&u32, num_columns:&u32, row_index:&u32, num_rows:&u32) {
-
+    pub(crate) fn adjustment_insert_coordinate(
+        &mut self,
+        sheet_name: &str,
+        column_index: &u32,
+        num_columns: &u32,
+        row_index: &u32,
+        num_rows: &u32,
+    ) {
         for worksheet in &mut self.work_sheet_collection {
-            worksheet.adjustment_insert_coordinate(sheet_name, column_index, num_columns, row_index, num_rows);
+            worksheet.adjustment_insert_coordinate(
+                sheet_name,
+                column_index,
+                num_columns,
+                row_index,
+                num_rows,
+            );
         }
     }
 
-    pub(crate) fn adjustment_remove_coordinate(&mut self, sheet_name:&str, column_index:&u32, num_columns:&u32, row_index:&u32, num_rows:&u32) {
+    pub(crate) fn adjustment_remove_coordinate(
+        &mut self,
+        sheet_name: &str,
+        column_index: &u32,
+        num_columns: &u32,
+        row_index: &u32,
+        num_rows: &u32,
+    ) {
         for worksheet in &mut self.work_sheet_collection {
-            worksheet.adjustment_remove_coordinate(sheet_name, column_index, num_columns, row_index, num_rows);
+            worksheet.adjustment_remove_coordinate(
+                sheet_name,
+                column_index,
+                num_columns,
+                row_index,
+                num_rows,
+            );
         }
     }
 
-    pub(crate) fn get_all_conditional_style_list(&self) -> Vec<(String, Style)> {
-        let mut result:Vec<(String, Style)> = Vec::new();
+    pub(crate) fn _get_all_conditional_style_list(&self) -> Vec<(String, Style)> {
+        let mut result: Vec<(String, Style)> = Vec::new();
         for work_sheet in &self.work_sheet_collection {
             for conditional_formatting in work_sheet.get_conditional_styles_collection() {
                 for conditional in conditional_formatting.get_conditional_collection() {
@@ -162,7 +207,7 @@ impl Spreadsheet {
                             if is_match == false {
                                 result.push((v.get_hash_code(), v.clone()));
                             }
-                        },
+                        }
                         None => {}
                     }
                 }
@@ -171,13 +216,17 @@ impl Spreadsheet {
         result
     }
 
-    pub fn get_cell_value_by_address<S: Into<String>>(&self, address:S) -> Vec<&CellValue> {
+    pub fn get_cell_value_by_address<S: Into<String>>(&self, address: S) -> Vec<&CellValue> {
         let (sheet_name, range) = split_address(address);
-        self.get_sheet_by_name(sheet_name).unwrap().get_cell_value_by_range(range)
+        self.get_sheet_by_name(sheet_name)
+            .unwrap()
+            .get_cell_value_by_range(range)
     }
 
-    pub(crate) fn get_cell_value_by_address_crate(&self, address:&Address) -> Vec<&CellValue> {
-        self.get_sheet_by_name(address.get_sheet_name()).unwrap().get_cell_value_by_range(address.get_range().get_range())
+    pub(crate) fn get_cell_value_by_address_crate(&self, address: &Address) -> Vec<&CellValue> {
+        self.get_sheet_by_name(address.get_sheet_name())
+            .unwrap()
+            .get_cell_value_by_range(address.get_range().get_range())
     }
 
     pub fn get_theme(&self) -> &Theme {
@@ -188,7 +237,7 @@ impl Spreadsheet {
         &mut self.theme
     }
 
-    pub(crate) fn set_theme(&mut self, value:Theme) {
+    pub(crate) fn set_theme(&mut self, value: Theme) {
         self.theme = value;
     }
 
@@ -208,8 +257,8 @@ impl Spreadsheet {
     pub fn get_properties_mut(&mut self) -> &mut Properties {
         &mut self.properties
     }
-    
-    pub fn set_properties(&mut self, value:Properties) {
+
+    pub fn set_properties(&mut self, value: Properties) {
         self.properties = value;
     }
 
@@ -221,7 +270,7 @@ impl Spreadsheet {
         &mut self.security
     }
 
-    pub fn set_security(&mut self, value:Security) {
+    pub fn set_security(&mut self, value: Security) {
         self.security = value;
     }
 
@@ -229,19 +278,19 @@ impl Spreadsheet {
         &self.macros_code
     }
 
-    pub(crate) fn set_macros_code(&mut self, value:Vec<u8>) {
+    pub(crate) fn set_macros_code(&mut self, value: Vec<u8>) {
         self.macros_code = Some(value);
     }
-    
+
     pub fn get_has_macros(&self) -> &bool {
         &self.has_macros
     }
 
-    pub(crate) fn get_has_macros_mut(&mut self) -> &mut bool {
+    pub(crate) fn _get_has_macros_mut(&mut self) -> &mut bool {
         &mut self.has_macros
     }
 
-    pub(crate) fn set_has_macros(&mut self, value:bool) {
+    pub(crate) fn set_has_macros(&mut self, value: bool) {
         self.has_macros = value;
     }
 
@@ -249,7 +298,7 @@ impl Spreadsheet {
         &self.unparsed_loaded_data
     }
 
-    pub fn set_unparsed_loaded_data(&mut self, value:Vec<String>) {
+    pub fn set_unparsed_loaded_data(&mut self, value: Vec<String>) {
         self.unparsed_loaded_data = value;
     }
 
@@ -257,11 +306,11 @@ impl Spreadsheet {
         &self.stylesheet
     }
 
-    pub(crate) fn get_stylesheet_mut(&mut self) -> &mut Stylesheet {
+    pub(crate) fn _get_stylesheet_mut(&mut self) -> &mut Stylesheet {
         &mut self.stylesheet
     }
 
-    pub(crate) fn set_stylesheet(&mut self, value:Stylesheet) -> &mut Self {
+    pub(crate) fn set_stylesheet(&mut self, value: Stylesheet) -> &mut Self {
         self.stylesheet = value;
         self
     }
@@ -275,11 +324,11 @@ impl Spreadsheet {
         &self.shared_string_table
     }
 
-    pub(crate) fn get_shared_string_table_mut(&mut self) -> &mut SharedStringTable {
+    pub(crate) fn _get_shared_string_table_mut(&mut self) -> &mut SharedStringTable {
         &mut self.shared_string_table
     }
 
-    pub(crate) fn set_shared_string_table(&mut self, value:SharedStringTable) -> &mut Self {
+    pub(crate) fn set_shared_string_table(&mut self, value: SharedStringTable) -> &mut Self {
         self.shared_string_table = value;
         self
     }
@@ -301,18 +350,18 @@ impl Spreadsheet {
         self.work_sheet_collection.len()
     }
 
-    pub fn get_sheet(&self, index:usize) -> Result<&Worksheet, &'static str> {
+    pub fn get_sheet(&self, index: usize) -> Result<&Worksheet, &'static str> {
         match &self.work_sheet_collection.get(index) {
             Some(v) => return Ok(v),
-            None => return Err("Not found.")
+            None => return Err("Not found."),
         }
     }
 
-    pub fn get_sheet_mut(&mut self, index:usize) -> &mut Worksheet {
+    pub fn get_sheet_mut(&mut self, index: usize) -> &mut Worksheet {
         self.work_sheet_collection.get_mut(index).unwrap()
     }
 
-    pub fn get_sheet_by_name<S: Into<String>>(&self, value:S) -> Result<&Worksheet, &'static str> {
+    pub fn get_sheet_by_name<S: Into<String>>(&self, value: S) -> Result<&Worksheet, &'static str> {
         let v = value.into();
         for sheet in &self.work_sheet_collection {
             if sheet.get_title() == &v {
@@ -322,7 +371,10 @@ impl Spreadsheet {
         Err("not found.")
     }
 
-    pub fn get_sheet_by_name_mut<S: Into<String>>(&mut self, value:S) -> Result<&mut Worksheet, &'static str> {
+    pub fn get_sheet_by_name_mut<S: Into<String>>(
+        &mut self,
+        value: S,
+    ) -> Result<&mut Worksheet, &'static str> {
         let v = value.into();
         for sheet in &mut self.work_sheet_collection {
             if sheet.get_title() == &v {
@@ -332,7 +384,10 @@ impl Spreadsheet {
         Err("not found.")
     }
 
-    pub(crate) fn get_sheet_by_sheet_id_mut<S: Into<String>>(&mut self, value:S) -> Result<&mut Worksheet, &'static str> {
+    pub(crate) fn get_sheet_by_sheet_id_mut<S: Into<String>>(
+        &mut self,
+        value: S,
+    ) -> Result<&mut Worksheet, &'static str> {
         let v = value.into();
         for sheet in &mut self.work_sheet_collection {
             if sheet.get_sheet_id() == &v {
@@ -342,27 +397,31 @@ impl Spreadsheet {
         Err("not found.")
     }
 
-    pub fn add_sheet(&mut self, value:Worksheet) -> Result<(), &'static str> {
+    pub fn add_sheet(&mut self, value: Worksheet) -> Result<(), &'static str> {
         let title = value.get_title();
         match Spreadsheet::check_sheet_title(self, title) {
-            Ok(_) => {},
-            Err(e) => return Err(e)
+            Ok(_) => {}
+            Err(e) => return Err(e),
         }
         self.work_sheet_collection.push(value);
         Ok(())
     }
 
-    pub fn new_sheet<S: Into<String>>(&mut self, value:S) -> Result<&mut Worksheet, &'static str> {
+    pub fn new_sheet<S: Into<String>>(&mut self, value: S) -> Result<&mut Worksheet, &'static str> {
         let v = value.into();
         match Spreadsheet::check_sheet_title(self, &v) {
-            Ok(_) => {},
-            Err(e) => return Err(e)
+            Ok(_) => {}
+            Err(e) => return Err(e),
         }
         let sheet_id = (self.work_sheet_collection.len() + 1).to_string();
         Ok(Spreadsheet::new_sheet_crate(self, sheet_id, v))
     }
 
-    pub(crate) fn new_sheet_crate<S: Into<String>>(&mut self, sheet_id:S, value:S) -> &mut Worksheet {
+    pub(crate) fn new_sheet_crate<S: Into<String>>(
+        &mut self,
+        sheet_id: S,
+        value: S,
+    ) -> &mut Worksheet {
         let mut worksheet = Worksheet::default();
         worksheet.set_sheet_id(sheet_id);
         worksheet.set_title(value.into());
@@ -370,22 +429,26 @@ impl Spreadsheet {
         self.work_sheet_collection.last_mut().unwrap()
     }
 
-    pub fn set_sheet_title<S: Into<String>>(&mut self, index:usize, value:S) -> Result<(), &'static str>{
+    pub fn set_sheet_title<S: Into<String>>(
+        &mut self,
+        index: usize,
+        value: S,
+    ) -> Result<(), &'static str> {
         let v = value.into();
         match Spreadsheet::check_sheet_title(self, &v) {
-            Ok(_) => {},
-            Err(e) => return Err(e)
+            Ok(_) => {}
+            Err(e) => return Err(e),
         }
         match self.work_sheet_collection.get_mut(index) {
             Some(sheet) => {
                 sheet.set_title(v);
                 Ok(())
-            },
-            None => return Err("sheet not found.")
+            }
+            None => return Err("sheet not found."),
         }
     }
 
-    pub(crate) fn check_sheet_title<S: Into<String>>(&self, value:S) -> Result<(), &'static str> {
+    pub(crate) fn check_sheet_title<S: Into<String>>(&self, value: S) -> Result<(), &'static str> {
         let v = value.into();
         for work_sheet in &self.work_sheet_collection {
             if &v == work_sheet.get_title() {
@@ -418,7 +481,7 @@ impl Spreadsheet {
         &mut self.workbook_view
     }
 
-    pub fn set_workbook_view(&mut self, value:WorkbookView) -> &mut Self {
+    pub fn set_workbook_view(&mut self, value: WorkbookView) -> &mut Self {
         self.workbook_view = value;
         self
     }
@@ -435,7 +498,7 @@ impl Spreadsheet {
     pub fn get_image_collection(&self) -> Vec<&Image> {
         let mut result: Vec<&Image> = Vec::new();
         for worksheet in self.get_sheet_collection() {
-            for picture in worksheet.get_worksheet_drawing().get_picture_collection() { 
+            for picture in worksheet.get_worksheet_drawing().get_picture_collection() {
                 let image = picture.get_blip_fill().get_blip().get_image();
                 let mut is_new = true;
                 for v in &result {
@@ -447,7 +510,7 @@ impl Spreadsheet {
                     result.push(image);
                 }
             }
-            for ole_objects in worksheet.get_ole_objects().get_ole_object() { 
+            for ole_objects in worksheet.get_ole_objects().get_ole_object() {
                 let image = ole_objects.get_embedded_object_properties().get_image();
                 let mut is_new = true;
                 for v in &result {
