@@ -4,23 +4,23 @@ pub struct StringValue {
     value_default: String,
 }
 impl StringValue {
-    pub(crate) fn get_value(&self)-> &str {
+    pub(crate) fn get_value(&self) -> &str {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default
+            None => &self.value_default,
         }
     }
 
-    pub(crate) fn get_value_string(&self)-> &str {
+    pub(crate) fn get_value_string(&self) -> &str {
         self.get_value()
     }
 
-    pub(crate) fn set_value<S: Into<String>>(&mut self, value:S) -> &mut StringValue {
+    pub(crate) fn set_value<S: Into<String>>(&mut self, value: S) -> &mut StringValue {
         self.value = Some(value.into());
         self
     }
 
-    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value:S) -> &mut StringValue {
+    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value: S) -> &mut StringValue {
         self.set_value(value.into())
     }
 
@@ -29,15 +29,14 @@ impl StringValue {
         self
     }
 
-    pub(crate) fn has_value(&self)-> bool {
+    pub(crate) fn has_value(&self) -> bool {
         match &self.value {
             Some(_) => true,
-            None => false
+            None => false,
         }
     }
 
-    pub(crate) fn get_hash_string(&self)-> &str
-    {
+    pub(crate) fn get_hash_string(&self) -> &str {
         if self.has_value() {
             return self.get_value_string();
         }
