@@ -14,24 +14,24 @@ impl Default for UInt32Value {
     }
 }
 impl UInt32Value {
-    pub(crate) fn get_value(&self)-> &u32 {
+    pub(crate) fn get_value(&self) -> &u32 {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default
+            None => &self.value_default,
         }
     }
 
-    pub(crate) fn get_value_string(&self)-> &str {
+    pub(crate) fn get_value_string(&self) -> &str {
         &self.value_string
     }
 
-    pub(crate) fn set_value(&mut self, value:u32) -> &mut Self {
+    pub(crate) fn set_value(&mut self, value: u32) -> &mut Self {
         self.value = Some(value);
         self.value_string = value.to_string();
         self
     }
 
-    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value:S) -> &mut Self {
+    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.set_value(value.into().parse::<u32>().unwrap())
     }
 
@@ -41,15 +41,14 @@ impl UInt32Value {
         self
     }
 
-    pub(crate) fn has_value(&self)-> bool {
+    pub(crate) fn has_value(&self) -> bool {
         match &self.value {
             Some(_) => true,
-            None => false
+            None => false,
         }
     }
 
-    pub(crate) fn get_hash_string(&self)-> &str
-    {
+    pub(crate) fn get_hash_string(&self) -> &str {
         if self.has_value() {
             return self.get_value_string();
         }
