@@ -8,21 +8,23 @@ pub enum VerticalAlignmentValues {
     Justify,
     Top,
 }
-impl Default for VerticalAlignmentValues  {
-    fn default() -> Self { Self::Top }
+impl Default for VerticalAlignmentValues {
+    fn default() -> Self {
+        Self::Top
+    }
 }
-impl EnumTrait for VerticalAlignmentValues  {
-    fn get_value_string(&self)->&str {
+impl EnumTrait for VerticalAlignmentValues {
+    fn get_value_string(&self) -> &str {
         match &self {
-            Self::Bottom => {"bottom"},
-            Self::Center => {"center"},
-            Self::Distributed => {"distributed"},
-            Self::Justify => {"justify"},
-            Self::Top => {"top"},
+            Self::Bottom => "bottom",
+            Self::Center => "center",
+            Self::Distributed => "distributed",
+            Self::Justify => "justify",
+            Self::Top => "top",
         }
     }
 }
-impl FromStr for VerticalAlignmentValues  {
+impl FromStr for VerticalAlignmentValues {
     type Err = ();
     fn from_str(input: &str) -> Result<Self, Self::Err> {
         match input {
@@ -31,8 +33,7 @@ impl FromStr for VerticalAlignmentValues  {
             "distributed" => Ok(Self::Distributed),
             "justify" => Ok(Self::Justify),
             "top" => Ok(Self::Top),
-            _      => Err(()),
+            _ => Err(()),
         }
     }
 }
- 
\ No newline at end of file
