@@ -1,16 +1,16 @@
-use quick_xml::events::{Event, BytesDecl};
-use quick_xml::Writer;
-use std::io;
-use ::structs::Worksheet;
 use super::driver::*;
 use super::XlsxError;
+use quick_xml::events::{BytesDecl, Event};
+use quick_xml::Writer;
+use std::io;
+use structs::Worksheet;
 
 const SUB_DIR: &'static str = "xl";
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     worksheet: &Worksheet,
     comment_id: &usize,
-    arv: &mut zip::ZipWriter<W>
+    arv: &mut zip::ZipWriter<W>,
 ) -> Result<(), XlsxError> {
     if worksheet.get_comments().len() == 0 {
         return Ok(());
@@ -20,13 +20,23 @@ pub(crate) fn write<W: io::Seek + io::Write>(
 
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
-    let _ = writer.write_event(Event::Decl(BytesDecl::new(b"1.0", Some(b"UTF-8"), Some(b"yes"))));
+    let _ = writer.write_event(Event::Decl(BytesDecl::new(
+        b"1.0",
+        Some(b"UTF-8"),
+        Some(b"yes"),
+    )));
     write_new_line(&mut writer);
 
     // comments
-    write_start_tag(&mut writer, "comments", vec![
-        ("xmlns", "http://schemas.openxmlformats.org/spreadsheetml/2006/main"),
-    ], false);
+    write_start_tag(
+        &mut writer,
+        "comments",
+        vec![(
+            "xmlns",
+            "http://schemas.openxmlformats.org/spreadsheetml/2006/main",
+        )],
+        false,
+    );
 
     // authors
     let authors = get_authors(worksheet);
@@ -44,10 +54,12 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         // comment
         let coordinate = comment.get_coordinate().get_coordinate();
         let author_id = get_author_id(&authors, comment.get_author());
-        write_start_tag(&mut writer, "comment", vec![
-            ("ref", &coordinate),
-            ("authorId", author_id.as_str()),
-        ], false);
+        write_start_tag(
+            &mut writer,
+            "comment",
+            vec![("ref", &coordinate), ("authorId", author_id.as_str())],
+            false,
+        );
 
         // text
         comment.get_text().write_to_text(&mut writer);
@@ -78,7 +90,7 @@ fn get_authors(worksheet: &Worksheet) -> Vec<String> {
     authors
 }
 
-fn get_author_id(authors:&Vec<String>, author:&str) -> String {
+fn get_author_id(authors: &Vec<String>, author: &str) -> String {
     let mut i = 0;
     for value in authors {
         if author == value {
