@@ -12,32 +12,83 @@ fn read_and_wite() {
     let b5_value = book.get_sheet(0).unwrap().get_value("B5");
     assert_eq!(" ", b5_value);
 
-    assert_eq!("1.0000",            book.get_sheet(0).unwrap().get_formatted_value_by_column_and_row(2, 20));
-    assert_eq!("$3,333.0000",       book.get_sheet(0).unwrap().get_formatted_value("B21"));
-    assert_eq!("$ 333.00",          book.get_sheet(0).unwrap().get_formatted_value("B22"));
-    assert_eq!("2020年3月",         book.get_sheet(0).unwrap().get_formatted_value("B23"));
-    assert_eq!("2:33 pm",           book.get_sheet(0).unwrap().get_formatted_value("B24"));
-    assert_eq!("5.00%",             book.get_sheet(0).unwrap().get_formatted_value("B25"));
-    assert_eq!("1/2",               book.get_sheet(0).unwrap().get_formatted_value("B26"));
-    assert_eq!("12/15/2020 14:01",  book.get_sheet(0).unwrap().get_formatted_value("B27"));
-    assert_eq!("444",               book.get_sheet(0).unwrap().get_formatted_value("B28"));
-    assert_eq!("14-Dec-20",         book.get_sheet(0).unwrap().get_formatted_value("B29"));
-    assert_eq!("2020年10月1日",     book.get_sheet(0).unwrap().get_formatted_value("B30"));
-    assert_eq!("1.2345",            book.get_sheet(0).unwrap().get_formatted_value("B31"));
-    assert_eq!("1.2",               book.get_sheet(0).unwrap().get_formatted_value("B32"));
-    assert_eq!("12,345,675,544.00", book.get_sheet(0).unwrap().get_formatted_value("B33"));
-    assert_eq!("1.235",             book.get_sheet(0).unwrap().get_formatted_value("B34"));
-    assert_eq!("1",                 book.get_sheet(0).unwrap().get_formatted_value("B35"));
-    assert_eq!("",                  book.get_sheet(0).unwrap().get_formatted_value("B36"));
-    assert_eq!("123456789012345678", book.get_sheet(0).unwrap().get_formatted_value("B37"));
+    assert_eq!(
+        "1.0000",
+        book.get_sheet(0)
+            .unwrap()
+            .get_formatted_value_by_column_and_row(2, 20)
+    );
+    assert_eq!(
+        "$3,333.0000",
+        book.get_sheet(0).unwrap().get_formatted_value("B21")
+    );
+    assert_eq!(
+        "$ 333.00",
+        book.get_sheet(0).unwrap().get_formatted_value("B22")
+    );
+    assert_eq!(
+        "2020年3月",
+        book.get_sheet(0).unwrap().get_formatted_value("B23")
+    );
+    assert_eq!(
+        "2:33 pm",
+        book.get_sheet(0).unwrap().get_formatted_value("B24")
+    );
+    assert_eq!(
+        "5.00%",
+        book.get_sheet(0).unwrap().get_formatted_value("B25")
+    );
+    assert_eq!("1/2", book.get_sheet(0).unwrap().get_formatted_value("B26"));
+    assert_eq!(
+        "12/15/2020 14:01",
+        book.get_sheet(0).unwrap().get_formatted_value("B27")
+    );
+    assert_eq!("444", book.get_sheet(0).unwrap().get_formatted_value("B28"));
+    assert_eq!(
+        "14-Dec-20",
+        book.get_sheet(0).unwrap().get_formatted_value("B29")
+    );
+    assert_eq!(
+        "2020年10月1日",
+        book.get_sheet(0).unwrap().get_formatted_value("B30")
+    );
+    assert_eq!(
+        "1.2345",
+        book.get_sheet(0).unwrap().get_formatted_value("B31")
+    );
+    assert_eq!("1.2", book.get_sheet(0).unwrap().get_formatted_value("B32"));
+    assert_eq!(
+        "12,345,675,544.00",
+        book.get_sheet(0).unwrap().get_formatted_value("B33")
+    );
+    assert_eq!(
+        "1.235",
+        book.get_sheet(0).unwrap().get_formatted_value("B34")
+    );
+    assert_eq!("1", book.get_sheet(0).unwrap().get_formatted_value("B35"));
+    assert_eq!("", book.get_sheet(0).unwrap().get_formatted_value("B36"));
+    assert_eq!(
+        "123456789012345678",
+        book.get_sheet(0).unwrap().get_formatted_value("B37")
+    );
 
-    let _ = book.get_sheet_by_name_mut("Sheet1").unwrap().get_cell_mut("A1")
-    .set_value("49046881.119999997");
+    let _ = book
+        .get_sheet_by_name_mut("Sheet1")
+        .unwrap()
+        .get_cell_mut("A1")
+        .set_value("49046881.119999997");
 
-    let _ = book.get_sheet_by_name_mut("Sheet1").unwrap().get_style_mut("A1")
-    .get_number_format_mut().set_format_code(umya_spreadsheet::NumberingFormat::FORMAT_NUMBER_COMMA_SEPARATED1);
+    let _ = book
+        .get_sheet_by_name_mut("Sheet1")
+        .unwrap()
+        .get_style_mut("A1")
+        .get_number_format_mut()
+        .set_format_code(umya_spreadsheet::NumberingFormat::FORMAT_NUMBER_COMMA_SEPARATED1);
 
-    let value =  book.get_sheet_by_name_mut("Sheet1").unwrap().get_formatted_value("A1");
+    let value = book
+        .get_sheet_by_name_mut("Sheet1")
+        .unwrap()
+        .get_formatted_value("A1");
     assert_eq!("49,046,881.12", &value);
 
     // writer
@@ -63,8 +114,16 @@ fn read_and_wite_xlsm() {
     let mut book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
 
     //let _ = book.get_sheet_mut(0).get_cell_mut("A1").set_value("TEST1");
-    let _ = book.get_sheet_mut(0).get_cell_by_column_and_row_mut(1, 1).set_value("TEST1");
-    let a1_value = book.get_sheet(0).unwrap().get_cell_by_column_and_row(1, 1).unwrap().get_value();
+    let _ = book
+        .get_sheet_mut(0)
+        .get_cell_by_column_and_row_mut(1, 1)
+        .set_value("TEST1");
+    let a1_value = book
+        .get_sheet(0)
+        .unwrap()
+        .get_cell_by_column_and_row(1, 1)
+        .unwrap()
+        .get_value();
     assert_eq!("TEST1", a1_value);
 
     // copy sheet
@@ -77,10 +136,7 @@ fn read_and_wite_xlsm() {
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("A1");
     to_marker.set_coordinate("B2");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::LineChart,
@@ -88,17 +144,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (pie chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("B1");
     to_marker.set_coordinate("C2");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::PieChart,
@@ -106,17 +162,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (doughnut chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("C1");
     to_marker.set_coordinate("D2");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::DoughnutChart,
@@ -124,17 +180,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
-    
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
+
     // add chart (area chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("D1");
     to_marker.set_coordinate("E2");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::AreaChart,
@@ -142,17 +198,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (bar chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("E1");
     to_marker.set_coordinate("F2");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::BarChart,
@@ -160,17 +216,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (bar 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("A2");
     to_marker.set_coordinate("B3");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::Bar3DChart,
@@ -178,17 +234,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (line 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("B2");
     to_marker.set_coordinate("C3");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::Line3DChart,
@@ -196,17 +252,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (pie 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("C2");
     to_marker.set_coordinate("D3");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::Pie3DChart,
@@ -214,17 +270,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (area 3d chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("D2");
     to_marker.set_coordinate("E3");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::Area3DChart,
@@ -232,17 +288,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (of pie chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("E2");
     to_marker.set_coordinate("F3");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::OfPieChart,
@@ -250,7 +306,10 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (bubble chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -269,7 +328,10 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (radar chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
@@ -288,17 +350,17 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // add chart (scatter chart)
     let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
     from_marker.set_coordinate("C3");
     to_marker.set_coordinate("D4");
-    let area_chart_series_list = vec![
-        "New Sheet!$G$7:$G$10",
-        "New Sheet!$H$7:$H$10",
-    ];
+    let area_chart_series_list = vec!["New Sheet!$G$7:$G$10", "New Sheet!$H$7:$H$10"];
     let mut chart = umya_spreadsheet::structs::Chart::default();
     chart.new_chart(
         umya_spreadsheet::structs::ChartType::ScatterChart,
@@ -306,7 +368,10 @@ fn read_and_wite_xlsm() {
         to_marker,
         area_chart_series_list,
     );
-    book.get_sheet_by_name_mut("Sheet7").unwrap().get_worksheet_drawing_mut().add_chart_collection(chart);
+    book.get_sheet_by_name_mut("Sheet7")
+        .unwrap()
+        .get_worksheet_drawing_mut()
+        .add_chart_collection(chart);
 
     // writer
     let path = std::path::Path::new("./tests/result_files/bbb.xlsm");
@@ -338,43 +403,147 @@ fn new_and_wite() {
 
     // new worksheet.
     let _ = book.new_sheet("Sheet2");
+    let _ = book.new_sheet("Sheet3");
 
     // change value.
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_mut("A1").set_value("TEST1");
-    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell("A1").unwrap().get_value();
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_cell_mut("A1")
+        .set_value("TEST1");
+    let a1_value = book
+        .get_sheet_by_name("Sheet2")
+        .unwrap()
+        .get_cell("A1")
+        .unwrap()
+        .get_value();
     assert_eq!("TEST1", a1_value);
 
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(2, 2).set_value_from_i32(1);
-    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(2, 2).unwrap().get_value();
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row_mut(2, 2)
+        .set_value_from_i32(1);
+    let a1_value = book
+        .get_sheet_by_name("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row(2, 2)
+        .unwrap()
+        .get_value();
     assert_eq!("1", a1_value);
 
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(2, 2).set_value_from_i32_ref(&1);
-    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(2, 2).unwrap().get_value();
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row_mut(2, 2)
+        .set_value_from_i32_ref(&1);
+    let a1_value = book
+        .get_sheet_by_name("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row(2, 2)
+        .unwrap()
+        .get_value();
     assert_eq!("1", a1_value);
 
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(3, 3).set_value_from_bool(true);
-    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(3, 3).unwrap().get_value();
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row_mut(3, 3)
+        .set_value_from_bool(true);
+    let a1_value = book
+        .get_sheet_by_name("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row(3, 3)
+        .unwrap()
+        .get_value();
     assert_eq!("TRUE", a1_value);
 
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_by_column_and_row_mut(3, 3).set_value_from_bool_ref(&true);
-    let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_cell_by_column_and_row(3, 3).unwrap().get_value();
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row_mut(3, 3)
+        .set_value_from_bool_ref(&true);
+    let a1_value = book
+        .get_sheet_by_name("Sheet2")
+        .unwrap()
+        .get_cell_by_column_and_row(3, 3)
+        .unwrap()
+        .get_value();
     assert_eq!("TRUE", a1_value);
 
     // add bottom border.
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_style_mut("A1")
-    .get_borders_mut()
-    .get_bottom_mut()
-    .set_border_style(umya_spreadsheet::Border::BORDER_MEDIUM);
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_style_by_column_and_row_mut(3, 2)
-    .get_borders_mut()
-    .get_left_mut()
-    .set_border_style(umya_spreadsheet::Border::BORDER_THIN);
-    
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_style_mut("A1")
+        .get_borders_mut()
+        .get_bottom_mut()
+        .set_border_style(umya_spreadsheet::Border::BORDER_MEDIUM);
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_style_by_column_and_row_mut(3, 2)
+        .get_borders_mut()
+        .get_left_mut()
+        .set_border_style(umya_spreadsheet::Border::BORDER_THIN);
+
     // change font color.
-    book.get_sheet_by_name_mut("Sheet2").unwrap().get_style_mut("A1")
-    .get_font_mut()
-    .get_color_mut()
-    .set_argb("00FF0000");
+    book.get_sheet_by_name_mut("Sheet2")
+        .unwrap()
+        .get_style_mut("A1")
+        .get_font_mut()
+        .get_color_mut()
+        .set_argb("00FF0000");
+
+    let worksheet = book.get_sheet_by_name_mut("Sheet3").unwrap();
+    worksheet.get_column_dimension_mut("A").set_auto_width(true);
+
+    worksheet.get_cell_mut("E1").set_value("テスト");
+    worksheet.get_cell_mut("E2").set_value("うみゃーねっと");
+    worksheet.get_cell_mut("E3").set_value("案案案案");
+    worksheet.get_column_dimension_mut("E").set_auto_width(true);
+
+    worksheet.get_cell_mut("F1").set_value("AAAAAAAAAAAAAAAAAA");
+    worksheet.get_cell_mut("F2").set_value("BBBBBBBBBBB");
+    worksheet
+        .get_cell_mut("F4")
+        .set_value("CCCCCCCCCCCCCCCCCCCCCCCCCC");
+    worksheet.get_column_dimension_mut("F").set_auto_width(true);
+
+    worksheet.get_cell_mut("G1").set_value("AAAAAAAAAAAAAAAAAA");
+    worksheet.get_cell_mut("G2").set_value("BBBBBBBBBBB");
+    worksheet
+        .get_cell_mut("G3")
+        .set_value("CCCCCCCCCCCCCCCCCCCCCCCCCC");
+    worksheet.get_column_dimension_mut("G").set_width(60f64);
+
+    worksheet.get_cell_mut("D1").set_value("テスト");
+    worksheet.get_cell_mut("D2").set_value("うみゃーねっと");
+    worksheet.get_cell_mut("D3").set_value("案案案案");
+    worksheet.get_column_dimension_mut("D").set_auto_width(true);
+
+    worksheet.get_cell_mut("H1").set_value("テスト");
+    worksheet
+        .get_cell_mut("H2")
+        .set_value("うみゃーねっと\nうみゃーねっと")
+        .get_style_mut()
+        .get_alignment_mut()
+        .set_wrap_text(true);
+    worksheet.get_cell_mut("H3").set_value("案案案案");
+    worksheet.get_column_dimension_mut("H").set_auto_width(true);
+
+    worksheet.get_cell_mut("I1").set_value("テスト");
+    worksheet
+        .get_cell_mut("I2")
+        .set_value("うみゃーねっと")
+        .get_style_mut()
+        .get_font_mut()
+        .get_font_size_mut()
+        .set_val(20f64);
+    worksheet.get_cell_mut("I3").set_value("案案案案");
+    worksheet.get_column_dimension_mut("I").set_auto_width(true);
+
+    worksheet
+        .get_cell_mut("J2")
+        .set_value("うみゃーねっと")
+        .get_style_mut()
+        .get_font_mut()
+        .get_font_size_mut()
+        .set_val(5f64);
+    worksheet.get_column_dimension_mut("J").set_auto_width(true);
 
     // writer.
     let path = std::path::Path::new("./tests/result_files/eee.xlsx");
